pub struct AdjointCheckpointWrapper(/* private fields */);Expand description
Wrapper for an adjoint checkpoint that allows it to be shared across threads and mutated safely.
Mutex is required because Checkpointing uses interior mutability when interpolating checkpoints