pub struct HostArray { /* private fields */ }Expand description
a read-only array that is allocated in rust and can be safely accessed in the host language (e.g. Python) without copying
Implementations
Sourceimpl HostArray
impl HostArray
pub fn new( ptr: *mut u8, shape: Vec<usize>, strides: Vec<usize>, dtype: ScalarType, ) -> Self
pub fn new_vector(ptr: *mut u8, len: usize, dtype: ScalarType) -> Self
pub fn alloc_vector(len: usize, dtype: ScalarType) -> Self
pub fn new_col_major( ptr: *mut u8, rows: usize, cols: usize, row_stride_elems: isize, col_stride_elems: isize, dtype: ScalarType, ) -> Self
pub fn as_array<'h, T: Scalar>( &self, ) -> Result<ArrayView2<'h, T>, DiffsolRtError>
pub fn as_slice<T: Scalar>(&self) -> Result<&[T], DiffsolRtError>