#[unsafe(no_mangle)]pub unsafe extern "C" fn diffsol_host_array_dim(
array: *const HostArray,
index: usize,
) -> usizeExpand description
Return the size of a single dimension in a host array.
Safety
array must be a valid pointer to a HostArray created by this library.
index must be in bounds for the array shape.