#[unsafe(no_mangle)]pub unsafe extern "C" fn diffsol_host_array_free(
array: *mut HostArray,
)Expand description
Free a host array previously returned by this library.
Safety
array must be either null or a pointer returned by this library that has
not already been freed.