#[unsafe(no_mangle)]pub unsafe extern "C" fn diffsol_host_array_ptr(
array: *const HostArray,
) -> *const u8Expand description
Return the raw data pointer stored by a host array.
Safety
array must be a valid pointer to a HostArray created by this library.
The returned pointer is borrowed and remains owned by the array.