diffsol_host_array_stride

Function diffsol_host_array_stride 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn diffsol_host_array_stride( array: *const HostArray, index: usize, ) -> usize
Return the stride, in bytes, for a single dimension in a host array.

Safety

array must be a valid pointer to a HostArray created by this library. index must be in bounds for the array shape.