pub enum JitBackendType {}Trait Implementations
Sourceimpl Clone for JitBackendType
impl Clone for JitBackendType
Sourcefn clone(&self) -> JitBackendType
fn clone(&self) -> JitBackendType
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for JitBackendType
impl Debug for JitBackendType
Sourceimpl<'de> Deserialize<'de> for JitBackendType
impl<'de> Deserialize<'de> for JitBackendType
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for JitBackendType
impl JsonSchema for JitBackendType
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for JitBackendType
impl PartialEq for JitBackendType
Sourcefn eq(&self, other: &JitBackendType) -> bool
fn eq(&self, other: &JitBackendType) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for JitBackendType
impl Serialize for JitBackendType
impl Copy for JitBackendType
impl Eq for JitBackendType
impl StructuralPartialEq for JitBackendType