Module jit_c

Module jit_c 

C FFI functions for querying JitBackendType enum values.

Provides extern "C" functions to enumerate available JIT backends, check whether a backend value is valid, and get the name string of a backend.

Functions

diffsol_jit_backend_type_count
Return the number of JIT backends compiled into this library.
diffsol_jit_backend_type_is_valid
Return whether a JIT backend enum value is valid.
diffsol_jit_backend_type_name
Return the name of a JIT backend enum value.