Module matrix_type_c

Module matrix_type_c 

C FFI functions for querying and converting MatrixType enum values.

Provides extern "C" functions to map between i32 values and the MatrixType enum variants, and to get the name of a matrix type as a C string.

Functions

diffsol_matrix_type_count
Return the number of matrix type enum values.
diffsol_matrix_type_is_valid
Return whether a matrix type enum value is valid.
diffsol_matrix_type_name
Return the name of a matrix type enum value.