diffsol_ode_free

Function diffsol_ode_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn diffsol_ode_free(ode: *mut OdeWrapper)
Free an ODE wrapper previously returned by this library.

Safety

ode must be either null or a pointer returned by this library that has not already been freed.