diffsol_ode_new_external_dynamic

Function diffsol_ode_new_external_dynamic 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn diffsol_ode_new_external_dynamic( path: *const c_char, matrix_type: i32, linear_solver: i32, ode_solver: i32, rhs_state_deps_ptr: *const DiffsolDepPair, rhs_state_deps_len: usize, rhs_input_deps_ptr: *const DiffsolDepPair, rhs_input_deps_len: usize, mass_state_deps_ptr: *const DiffsolDepPair, mass_state_deps_len: usize, ) -> *mut OdeWrapper
Construct a dynamic-library-backed ODE wrapper.

Safety

path must be a valid, null-terminated UTF-8 string for the duration of this call. Dependency pointers must be either null with length 0 or point to valid memory containing DiffsolDepPair values for the specified lengths for the duration of this call.