diffsol_ode_rhs

Function diffsol_ode_rhs 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn diffsol_ode_rhs( ode: *mut OdeWrapper, params_ptr: *const f64, params_len: usize, t: f64, y_ptr: *const f64, y_len: usize, out_array: *mut *mut HostArray, ) -> i32
Evaluate the ODE right-hand side at a given time and state.

Safety

ode must be a valid mutable pointer created by this library. params_ptr and y_ptr must point to readable f64 buffers of the specified lengths, unless the corresponding length is zero. out_array must be writable.