diffsol_ode_solve_dense

Function diffsol_ode_solve_dense 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn diffsol_ode_solve_dense( ode: *mut OdeWrapper, params_ptr: *const f64, params_len: usize, t_eval_ptr: *const f64, t_eval_len: usize, out_solution: *mut *mut SolutionWrapper, ) -> i32
Solve an ODE and sample the solution at requested times.

Safety

ode must be a valid mutable pointer created by this library. params_ptr and t_eval_ptr must point to readable f64 buffers of the specified lengths, unless the corresponding length is zero. out_solution must be writable.