Module ode_solver_type

Module ode_solver_type 

ODE solver method type.

This module defines OdeSolverType, an enum specifying which ODE integration method to use:

The internal solve methods on this enum dispatch to the appropriate diffsol solver type via tag structs defined in the private ode_solver_tag module.

Enums

OdeSolverType
Enumerates the possible ODE solver methods for diffsol. See the solver descriptions in the diffsol documentation (https://github.com/martinjrobins/diffsol) for more details.