diffsol_solution_wrapper_free

Function diffsol_solution_wrapper_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn diffsol_solution_wrapper_free( solution: *mut SolutionWrapper, )
Free a solution wrapper previously returned by this library.

Safety

solution must be either null or a pointer returned by this library that has not already been freed.