#[unsafe(no_mangle)]pub unsafe extern "C" fn diffsol_solution_wrapper_get_ts(
solution: *const SolutionWrapper,
out_array: *mut *mut HostArray,
) -> i32Expand description
Return the recorded solution times as a host array.
Safety
solution must be a valid pointer created by this library. out_array
must be a valid, writable pointer to receive ownership of the returned array.