diffsol_solution_wrapper_get_ys

Function diffsol_solution_wrapper_get_ys 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn diffsol_solution_wrapper_get_ys( solution: *const SolutionWrapper, out_array: *mut *mut HostArray, ) -> i32
Return the recorded solution values as a host array.

Safety

solution must be a valid pointer created by this library. out_array must be a valid, writable pointer to receive ownership of the returned array.