diffsol_alloc_string

Function diffsol_alloc_string 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn diffsol_alloc_string( size: usize, ) -> *mut c_char
Allocate memory for a string of given size (including null terminator) Returns a pointer to writable memory that TypeScript can write to

Safety

The returned pointer must be released with diffsol_free_string using the same size. The caller must not read or write beyond the allocated buffer.