Utility functions for querying library capabilities.
Provides standalone functions useful for runtime capability checks:
- version โ returns the crate version string.
- is_klu_available โ returns
trueif thesuitesparsefeature (KLU sparse linear solver) was enabled at compile time. - is_sens_available โ returns
trueif sensitivity analysis is supported on the current platform (not Windows).
Functions
- is_
klu_ available - Inidicate whether Klu functions are available. This depends on whether the library was built with suitesparse support.
- is_
sens_ available - Inidicate whether sensitivity analysis is available. Sensitivity analysis is currently limited to Linux and macos, and not supported for Windows.
- version
- get version of the library from Cargo.toml