Module valid_linear_solver

Module valid_linear_solver 

Internal validation of linear solver compatibility with matrix types.

Provides validate_linear_solver::<M>(linear_solver) which checks that a given LinearSolverType is compatible with a matrix type M. For example, KLU is only valid for FaerSparseMat<f64> when the suitesparse feature is enabled. Uses LuValidator<M> and KluValidator<M> traits to associate each matrix type with its valid linear solver implementations.