Functions
- diffsol_
clear_ ⚠last_ error - Clear the last error for the current thread.
- diffsol_
error ⚠ - Return the last error message for the current thread, if any.
- diffsol_
error_ ⚠code - Return whether thread-local error state is currently set.
- diffsol_
last_ ⚠error_ file - Return the source file associated with the last error for the current thread.
- diffsol_
last_ ⚠error_ line - Return the source line associated with the last error for the current thread.
- diffsol_
last_ ⚠error_ message - Return the last error message for the current thread, if any.