Module error_c

Module error_c 

Functions

diffsol_clear_last_error
Clear the last error for the current thread.
diffsol_error
Return the last error message for the current thread, if any.
diffsol_error_code
Return whether thread-local error state is currently set.
diffsol_last_error_file
Return the source file associated with the last error for the current thread.
diffsol_last_error_line
Return the source line associated with the last error for the current thread.
diffsol_last_error_message
Return the last error message for the current thread, if any.