C FFI functions for inspecting and freeing HostArray objects.
Provides extern "C" functions for querying HostArray metadata (dimensions, strides,
data type, raw pointer) and for freeing a HostArray previously returned by this library.
Functions
- diffsol_
host_ ⚠array_ alloc_ vector - Allocate a one-dimensional host array of the requested length and scalar type.
- diffsol_
host_ ⚠array_ dim - Return the size of a single dimension in a host array.
- diffsol_
host_ ⚠array_ dtype - Return the scalar type enum stored by a host array.
- diffsol_
host_ ⚠array_ free - Free a host array previously returned by this library.
- diffsol_
host_ ⚠array_ ndim - Return the number of dimensions in a host array.
- diffsol_
host_ ⚠array_ ptr - Return the raw data pointer stored by a host array.
- diffsol_
host_ ⚠array_ stride - Return the stride, in bytes, for a single dimension in a host array.