#[unsafe(no_mangle)]pub unsafe extern "C" fn diffsol_host_array_alloc_vector(
len: usize,
dtype: i32,
) -> *mut HostArrayExpand description
Allocate a one-dimensional host array of the requested length and scalar type.
Safety
The returned pointer must be freed with diffsol_host_array_free. dtype
must be a valid scalar type enum defined by this library.