diffsol_host_array_ndim

Function diffsol_host_array_ndim 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn diffsol_host_array_ndim( array: *const HostArray, ) -> usize
Return the number of dimensions in a host array.

Safety

array must be a valid pointer to a HostArray created by this library.