C FFI functions for querying and converting MatrixType enum values.
Provides extern "C" functions to map between i32 values and the MatrixType enum
variants, and to get the name of a matrix type as a C string.
Functions
- diffsol_
matrix_ ⚠type_ count - Return the number of matrix type enum values.
- diffsol_
matrix_ ⚠type_ is_ valid - Return whether a matrix type enum value is valid.
- diffsol_
matrix_ ⚠type_ name - Return the name of a matrix type enum value.