Module matrix_type_c
diffsol_
c
0.2.0
Module matrix_
type_
c
Module Items
Functions
In crate diffsol_
c
diffsol_c
Module
matrix_
type_
c
Functions

diffsol_
matrix_
type_
count
⚠
Return the number of matrix type enum values.
diffsol_
matrix_
type_
is_
valid
⚠
Return whether a matrix type enum value is valid.
diffsol_
matrix_
type_
name
⚠
Return the name of a matrix type enum value.