Structs
- Diffsol
DepPair - C-compatible dependency pair used by the FFI constructors.
Functions
- diffsol_
host_ ⚠array_ list_ free - Free a list of host arrays previously returned by this library.
- diffsol_
ode_ ⚠free - Free an ODE wrapper previously returned by this library.
- diffsol_
ode_ ⚠get_ atol - Return the absolute tolerance configured for an ODE.
- diffsol_
ode_ ⚠get_ h0 - Return the initial step size configured for an ODE.
- diffsol_
ode_ ⚠get_ ic_ options - Return a handle to the initial-condition solver options for an ODE.
- diffsol_
ode_ ⚠get_ integrate_ out - Return whether output equations are integrated alongside state equations.
- diffsol_
ode_ ⚠get_ linear_ solver - Return the linear solver enum configured for an ODE.
- diffsol_
ode_ ⚠get_ matrix_ type - Return the matrix type configured for an ODE.
- diffsol_
ode_ ⚠get_ ode_ solver - Return the ODE solver enum configured for an ODE.
- diffsol_
ode_ ⚠get_ options - Return a handle to the ODE solver options for an ODE.
- diffsol_
ode_ ⚠get_ out_ atol - Return the optional output absolute tolerance.
- diffsol_
ode_ ⚠get_ out_ rtol - Return the optional output relative tolerance.
- diffsol_
ode_ ⚠get_ param_ atol - Return the optional adjoint parameter absolute tolerance.
- diffsol_
ode_ ⚠get_ param_ rtol - Return the optional adjoint parameter relative tolerance.
- diffsol_
ode_ ⚠get_ rtol - Return the relative tolerance configured for an ODE.
- diffsol_
ode_ ⚠get_ sens_ atol - Return the optional sensitivity absolute tolerance.
- diffsol_
ode_ ⚠get_ sens_ rtol - Return the optional sensitivity relative tolerance.
- diffsol_
ode_ ⚠get_ t0 - Return the initial time configured for an ODE.
- diffsol_
ode_ ⚠new_ external_ dynamic - Construct a dynamic-library-backed ODE wrapper.
- diffsol_
ode_ ⚠rhs - Evaluate the ODE right-hand side at a given time and state.
- diffsol_
ode_ ⚠rhs_ jac_ mul - Evaluate the ODE Jacobian-vector product at a given time and state.
- diffsol_
ode_ ⚠set_ atol - Set the absolute tolerance for an ODE.
- diffsol_
ode_ ⚠set_ h0 - Set the initial step size for an ODE.
- diffsol_
ode_ ⚠set_ integrate_ out - Set whether output equations are integrated alongside state equations.
- diffsol_
ode_ ⚠set_ linear_ solver - Set the linear solver enum for an ODE.
- diffsol_
ode_ ⚠set_ ode_ solver - Set the ODE solver enum for an ODE.
- diffsol_
ode_ ⚠set_ out_ atol - Set the optional output absolute tolerance.
- diffsol_
ode_ ⚠set_ out_ rtol - Set the optional output relative tolerance.
- diffsol_
ode_ ⚠set_ param_ atol - Set the optional adjoint parameter absolute tolerance.
- diffsol_
ode_ ⚠set_ param_ rtol - Set the optional adjoint parameter relative tolerance.
- diffsol_
ode_ ⚠set_ rtol - Set the relative tolerance for an ODE.
- diffsol_
ode_ ⚠set_ sens_ atol - Set the optional sensitivity absolute tolerance.
- diffsol_
ode_ ⚠set_ sens_ rtol - Set the optional sensitivity relative tolerance.
- diffsol_
ode_ ⚠set_ t0 - Set the initial time for an ODE.
- diffsol_
ode_ ⚠solve - Solve an ODE up to a final time.
- diffsol_
ode_ ⚠solve_ dense - Solve an ODE and sample the solution at requested times.
- diffsol_
ode_ ⚠solve_ fwd_ sens - Solve an ODE and sample forward sensitivities at requested times.
- diffsol_
ode_ ⚠y0 - Evaluate the initial condition vector for an ODE.