Structs
- Diffsol
DepPair - C-compatible dependency pair used by the FFI constructors.
Functions
- diffsol_
host_ ⚠array_ list_ free - Free a list of host arrays previously returned by this library.
- diffsol_
ode_ ⚠free - Free an ODE wrapper previously returned by this library.
- diffsol_
ode_ ⚠get_ atol - Return the absolute tolerance configured for an ODE.
- diffsol_
ode_ ⚠get_ ic_ options - Return a handle to the initial-condition solver options for an ODE.
- diffsol_
ode_ ⚠get_ linear_ solver - Return the linear solver enum configured for an ODE.
- diffsol_
ode_ ⚠get_ matrix_ type - Return the matrix type configured for an ODE.
- diffsol_
ode_ ⚠get_ ode_ solver - Return the ODE solver enum configured for an ODE.
- diffsol_
ode_ ⚠get_ options - Return a handle to the ODE solver options for an ODE.
- diffsol_
ode_ ⚠get_ rtol - Return the relative tolerance configured for an ODE.
- diffsol_
ode_ ⚠new_ external_ dynamic - Construct a dynamic-library-backed ODE wrapper.
- diffsol_
ode_ ⚠rhs - Evaluate the ODE right-hand side at a given time and state.
- diffsol_
ode_ ⚠rhs_ jac_ mul - Evaluate the ODE Jacobian-vector product at a given time and state.
- diffsol_
ode_ ⚠set_ atol - Set the absolute tolerance for an ODE.
- diffsol_
ode_ ⚠set_ linear_ solver - Set the linear solver enum for an ODE.
- diffsol_
ode_ ⚠set_ ode_ solver - Set the ODE solver enum for an ODE.
- diffsol_
ode_ ⚠set_ rtol - Set the relative tolerance for an ODE.
- diffsol_
ode_ ⚠solve - Solve an ODE up to a final time.
- diffsol_
ode_ ⚠solve_ dense - Solve an ODE and sample the solution at requested times.
- diffsol_
ode_ ⚠solve_ fwd_ sens - Solve an ODE and sample forward sensitivities at requested times.
- diffsol_
ode_ ⚠solve_ hybrid - Solve a hybrid ODE up to a final time, automatically applying resets after roots.
- diffsol_
ode_ ⚠solve_ hybrid_ dense - Solve a hybrid ODE and sample the solution at requested times.
- diffsol_
ode_ ⚠solve_ hybrid_ fwd_ sens - Solve a hybrid ODE with forward sensitivities at requested times.
- diffsol_
ode_ ⚠solve_ sum_ squares_ adj - Solve the sum-of-squares adjoint problem for an ODE.
- diffsol_
ode_ ⚠y0 - Evaluate the initial condition vector for an ODE.