#[unsafe(no_mangle)]pub unsafe extern "C" fn diffsol_host_array_list_free(
list: *mut *mut HostArray,
len: usize,
)Expand description
Free a list of host arrays previously returned by this library.
Safety
list must be either null or a pointer returned by this library for a list
of length len. Each pointed-to element remains owned separately.