diffsol_ode_get_options

Function diffsol_ode_get_options 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn diffsol_ode_get_options( ode: *const OdeWrapper, out_options: *mut *mut OdeSolverOptions, ) -> i32
Return a handle to the ODE solver options for an ODE.

Safety

ode must be a valid pointer created by this library. out_options must be a valid, writable pointer to receive ownership of the returned options object.