ODE solver method type.
This module defines OdeSolverType, an enum specifying which ODE integration method to use:
- OdeSolverType::Bdf — Backward Differentiation Formula (stiff ODEs, singular mass matrices).
- OdeSolverType::Esdirk34 — Explicit Singly Diagonally Implicit Runge-Kutta (moderately stiff).
- OdeSolverType::TrBdf2 — Trapezoidal BDF of order 2 (moderately stiff).
- OdeSolverType::Tsit45 — Tsitouras 4/5th order Explicit Runge-Kutta (non-stiff, explicit).
The internal solve methods on this enum dispatch to the appropriate diffsol solver type
via tag structs defined in the private ode_solver_tag module.
Enums
- OdeSolver
Type - Enumerates the possible ODE solver methods for diffsol. See the solver descriptions in the diffsol documentation (https://github.com/martinjrobins/diffsol) for more details.