Module solution_wrapper_c

Module solution_wrapper_c 

Functions

diffsol_solution_wrapper_free
Free a solution wrapper previously returned by this library.
diffsol_solution_wrapper_get_sens
Return the recorded forward sensitivities as a list of host arrays.
diffsol_solution_wrapper_get_ts
Return the recorded solution times as a host array.
diffsol_solution_wrapper_get_ys
Return the recorded solution values as a host array.