diffsol_solution_wrapper_get_sens

Function diffsol_solution_wrapper_get_sens 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn diffsol_solution_wrapper_get_sens( solution: *const SolutionWrapper, out_sens: *mut *mut *mut HostArray, out_sens_len: *mut usize, ) -> i32
Return the recorded forward sensitivities as a list of host arrays.

Safety

solution must be a valid pointer created by this library. out_sens and out_sens_len must be valid, writable pointers to receive the result.